@@ -9,7 +9,7 @@
  * non-increasing between subsequent iterations. Both of the update rules
  * for W and H are defined in this file.
  *
- * This file is part of MLPACK 1.0.9.
+ * This file is part of MLPACK 1.0.10.
  *
  * MLPACK is free software: you can redistribute it and/or modify it under the
  * terms of the GNU Lesser General Public License as published by the Free
@@ -42,7 +42,7 @@ class NMFMultiplicativeDistanceUpdate
   NMFMultiplicativeDistanceUpdate() { }
 
   template<typename MatType>
-  void Initialize(const MatType& dataset, const long rank)
+  void Initialize(const MatType& dataset, const size_t rank)
   {
         (void)dataset;
         (void)rank;
